@@ -1,5 +1,7 @@
+import json
+
 from django.core.paginator import InvalidPage
-from django.http import Http404, HttpResponseRedirect, JsonResponse
+from django.http import Http404, HttpResponse, HttpResponseRedirect, JsonResponse
 from django.utils.translation import gettext_lazy as _
 from django.views.generic import DetailView, ListView
 from django.views.generic.edit import DeleteView, FormView
@@ -8,7 +10,7 @@ from . import status
 from .mixins import BaseViewMixin
 from .paginators import ClientAPIPagination
 from .settings import api_client_settings
-from .utils import clean_url
+from .utils import clean_url, to_dict
 
 
 class ClientMethodMixin:
@@ -29,7 +31,7 @@ class ClientAPIFormView(FormView):
     def send_cleaned_data(self, response, form):
         if response.raw.status_code not in [status.HTTP_201_CREATED, status.HTTP_200_OK]:
             errors = response.raw.json()
-            if isinstance(errors, str):
+            if not isinstance(errors, dict):
                 errors = {'non_field_errors': errors}
             for error_key in errors:
                 if error_key == 'non_field_errors':
@@ -99,6 +101,7 @@ class ClientAPIAuthenticatedListView(ClientMethodMixin, ListView):
     api_filters = []
     page_base_url = ''
     page_title = ''
+    ajax_response_type = 'html'
 
     def get_paginate_by(self):
         """
@@ -175,7 +178,7 @@ class ClientAPIAuthenticatedListView(ClientMethodMixin, ListView):
 
         pagination_params = ['search', 'paginate_by', 'ordering'] + self.api_filters
         context['append_param'] = '&' if any(
-            [True for x in pagination_params if x in search_url]) else '?'
+            [True for x in pagination_params if x in self.request.GET.keys()]) else '?'
 
         return context
 
@@ -185,6 +188,10 @@ class ClientAPIAuthenticatedListView(ClientMethodMixin, ListView):
             params['filter_params'] = True
 
         context = self.get_context_data(**params)
+        if request.is_ajax() and self.ajax_response_type == 'json':
+            results = to_dict(context['object_list'])
+            return HttpResponse(json.dumps(results))
+
         self.object_list = context['object_list']
 
         if params:
